<script setup>
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import Checkbox from '@/Components/Checkbox.vue';
import { Link, useForm, usePage } from '@inertiajs/vue3';
import { ref, onMounted } from 'vue';

defineProps({
    mustVerifyEmail: {
        type: Boolean,
    },
    status: {
        type: String,
    },
});

const user = usePage().props.auth.user;
console.log(user.subscribe);
const form = useForm({
    name: user.name,
    email: user.email,
    company: user.company,
    address1: user.address1,
    address2: user.address2,
    city: user.city,
    state: user.state,
    postal: user.postal,
    country: user.country,
    phone: user.phone,
    fax: user.fax,
    subscribe: user.subscribe,
});
const subscribe = ref('');

const checkSubscribed = () => {
    if(user.subscribe == 1) {
        subscribe.value = 1;
    }
}

onMounted(() => {
    checkSubscribed();
});
</script>

<template>
    <section>
        <header>
            <h2 class="text-lg font-medium text-gray-900">Profile Information</h2>

            <p class="mt-1 text-sm text-gray-600">
                Update your account's profile information and email address.
            </p>
        </header>

        <form @submit.prevent="form.patch(route('profile.update'))" class="mt-6 space-y-6">
            <div>
                <InputLabel for="name" value="Name" />

                <TextInput
                    id="name"
                    type="text"
                    class="mt-1 block w-full"
                    v-model="form.name"
                    required
                    autofocus
                    autocomplete="name"
                />

                <InputError class="mt-2" :message="form.errors.name" />
            </div>

            <div>
                <InputLabel for="company" value="Company" />

                <TextInput
                    id="company"
                    type="text"
                    class="mt-1 block w-full"
                    v-model="form.company"
                    required
                    autofocus
                    autocomplete="company"
                    disabled="disabled"
                />

                <InputError class="mt-2" :message="form.errors.company" />
            </div>

            <div>
                <InputLabel for="address1" value="Address Line 1" />

                <TextInput
                    id="address1"
                    type="text"
                    class="mt-1 block w-full"
                    v-model="form.address1"
                    disabled="disabled"
                    autofocus
                />

                <InputError class="mt-2" :message="form.errors.address1" />
            </div>

            <div>
                <InputLabel for="address2" value="Address Line 2" />

                <TextInput
                    id="address2"
                    type="text"
                    class="mt-1 block w-full"
                    v-model="form.address2"
                    disabled="disabled"
                    autofocus
                />

                <InputError class="mt-2" :message="form.errors.address2" />
            </div>

            <div>
                <InputLabel for="city" value="City" />

                <TextInput
                    id="city"
                    type="text"
                    class="mt-1 block w-full"
                    v-model="form.city"
                    disabled="disabled"
                    autofocus
                />

                <InputError class="mt-2" :message="form.errors.city" />
            </div>

            <div>
                <InputLabel for="state" value="State" />

                <TextInput
                    id="state"
                    type="text"
                    class="mt-1 block w-full"
                    v-model="form.state"
                    disabled="disabled"
                    autofocus
                />

                <InputError class="mt-2" :message="form.errors.state" />
            </div>

            <div>
                <InputLabel for="postal" value="Zip/Postal Code" />

                <TextInput
                    id="postal"
                    type="text"
                    class="mt-1 block w-full"
                    v-model="form.postal"
                    autofocus
                    disabled="disabled"
                    autocomplete="postal"
                />

                <InputError class="mt-2" :message="form.errors.postal" />
            </div>

            <div>
                <InputLabel for="country" value="Country" />

                <TextInput
                    id="country"
                    type="text"
                    class="mt-1 block w-full"
                    v-model="form.country"
                    autofocus
                    disabled="disabled"
                    autocomplete="country"
                />

                <InputError class="mt-2" :message="form.errors.country" />
            </div>

            <div>
                <InputLabel for="phone" value="Phone" />

                <TextInput
                    id="phone"
                    type="text"
                    class="mt-1 block w-full"
                    v-model="form.phone"
                    autofocus
                    autocomplete="phone"
                />

                <InputError class="mt-2" :message="form.errors.phone" />
            </div>

            <div>
                <InputLabel for="fax" value="Fax" />

                <TextInput
                    id="fax"
                    type="text"
                    class="mt-1 block w-full"
                    v-model="form.fax"
                    autofocus
                    autocomplete="fax"
                />

                <InputError class="mt-2" :message="form.errors.fax" />
            </div>

            <div>
                <InputLabel for="email" value="Email" />

                <TextInput
                    id="email"
                    type="email"
                    class="mt-1 block w-full"
                    v-model="form.email"
                    autocomplete="username"
                />

                <InputError class="mt-2" :message="form.errors.email" />
            </div>

            <div class="block mt-4">
                <label class="flex items-center">
                    <Checkbox name="subscribe" :checked="subscribe==1" v-model="form.subscribe" :value="form.subscribe" />
                    <span class="ms-2 text-sm text-gray-600">Subscribe to newsletter</span>
                </label>
            </div>

            <div v-if="mustVerifyEmail && user.email_verified_at === null">
                <p class="text-sm mt-2 text-gray-800">
                    Your email address is unverified.
                    <Link
                        :href="route('verification.send')"
                        method="post"
                        as="button"
                        class="underline text-sm text-gray-600 hover:text-gray-900 rounded-md focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
                    >
                        Click here to re-send the verification email.
                    </Link>
                </p>

                <div
                    v-show="status === 'verification-link-sent'"
                    class="mt-2 font-medium text-sm text-green-600"
                >
                    A new verification link has been sent to your email address.
                </div>
            </div>

            <div class="flex items-center gap-4">
                <PrimaryButton :disabled="form.processing">Save</PrimaryButton>

                <Transition
                    enter-active-class="transition ease-in-out"
                    enter-from-class="opacity-0"
                    leave-active-class="transition ease-in-out"
                    leave-to-class="opacity-0"
                >
                    <p v-if="form.recentlySuccessful" class="text-sm text-gray-600">Saved.</p>
                </Transition>
            </div>
        </form>
    </section>
</template>
